# [1.8.6](https://github.com/seriaati/ambr/compare/v1.8.5..v1.8.6) - 2025-08-22

## Bug Fixes

- Handle int val in Story.tips - ([3d4ab06](https://github.com/seriaati/ambr/commit/3d4ab06004b595308aabe612a7578c9ce1f0228d))
- Remove link tags from descriptions - ([780b5cf](https://github.com/seriaati/ambr/commit/780b5cf1f6802263ac2cf8e67ade4f48e410443b))

## Continuous Integrations

- Remove Python version specifier in release.yml - ([24faede](https://github.com/seriaati/ambr/commit/24faede063db93d2f84328cd430631f87ac87751))
- Add bump version workflow - ([4db755d](https://github.com/seriaati/ambr/commit/4db755ddf5b3849c955f17f1eb7e1be99710bd1c))

## Features

- Add fetch_story param to fetch_artifact_set_detail() - ([9c67f51](https://github.com/seriaati/ambr/commit/9c67f51a5fbedb2e83f3525d2fdedc1a6e16dbdc))

## Miscellaneous Chores

- **(deps)** lock file maintenance (#99) - ([449926d](https://github.com/seriaati/ambr/commit/449926d710ea7b0dd8e0255771ee99e469c94d81))
- **(deps)** lock file maintenance (#100) - ([c3d0894](https://github.com/seriaati/ambr/commit/c3d08940c05944d6a618df52ba53fcd6da2319e7))
- **(deps)** lock file maintenance (#101) - ([a5bf9ac](https://github.com/seriaati/ambr/commit/a5bf9ac93a57fad299d3d4d77a96ff310748b756))
- **(deps)** lock file maintenance (#102) - ([058f430](https://github.com/seriaati/ambr/commit/058f4309b33d6956eeae74c17375a525cabd380a))
- **(deps)** lock file maintenance (#103) - ([778bde3](https://github.com/seriaati/ambr/commit/778bde38c18a77869f3e504e1fb3f6fd3a0c2743))
- **(deps)** lock file maintenance (#104) - ([93de3d6](https://github.com/seriaati/ambr/commit/93de3d6bb367b59aab350e4b5d704b89725334ea))
- **(deps)** lock file maintenance (#105) - ([5ddb94f](https://github.com/seriaati/ambr/commit/5ddb94ff7e5d893af229672fc528b841ea54b2ef))
- **(deps)** lock file maintenance (#106) - ([a6e650e](https://github.com/seriaati/ambr/commit/a6e650e372344423488cac5370c00256dd4e90d1))
- **(deps)** lock file maintenance (#107) - ([e1bcb4f](https://github.com/seriaati/ambr/commit/e1bcb4fa7635ff0cce2708e845daf97fcdf724f7))
- **(deps)** lock file maintenance (#108) - ([ba59cbe](https://github.com/seriaati/ambr/commit/ba59cbe00ea0d4de3578de96fdfcff7eca3bccec))
- **(deps)** lock file maintenance (#109) - ([2e5e8c5](https://github.com/seriaati/ambr/commit/2e5e8c5e25b263a5ee92d9cc3f6f0385dba27883))
- **(deps)** lock file maintenance (#110) - ([af5cf8d](https://github.com/seriaati/ambr/commit/af5cf8de0d88d78cb810c7eecdf91ff6141cc03e))
- **(deps)** lock file maintenance (#111) - ([ce47a2b](https://github.com/seriaati/ambr/commit/ce47a2bf56bf39c9ab1a915647b50586a31ab377))
- **(deps)** lock file maintenance (#112) - ([aa3418d](https://github.com/seriaati/ambr/commit/aa3418d051175185d89e8a060c8badfbe3705669))
- **(deps)** lock file maintenance (#113) - ([499564b](https://github.com/seriaati/ambr/commit/499564b1bf39497232cfef973c86e98a2e009069))
- **(deps)** update actions/checkout action to v5 (#114) - ([b1677a8](https://github.com/seriaati/ambr/commit/b1677a82d922237ef9a95d58379efea541027b84))
- **(deps)** lock file maintenance (#115) - ([83ef9bd](https://github.com/seriaati/ambr/commit/83ef9bdfed23e9c53bb9639bd0ed92772752b757))

## Refactoring

- Replace verbose import block with single import - ([e5f53ba](https://github.com/seriaati/ambr/commit/e5f53ba42936b7bc541e159def54ea9c9805f198))

<!-- generated by git-cliff -->
